@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Yaml;
-$Config::Model::Backend::Yaml::VERSION = '2.132';
+$Config::Model::Backend::Yaml::VERSION = '2.134';
 use 5.10.1;
 use Carp;
 use strict;
@@ -52,7 +52,7 @@ sub read {
     return 0 unless $args{file_path}->exists;    # no file to read
 
     # load yaml file
-    my $yaml = $args{file_path}->slurp_utf8;
+    my $yaml = $args{file_path}->slurp_raw;
 
     # convert to perl data
     my $perl_data = Load($yaml) ;
@@ -97,7 +97,7 @@ sub write {
 
     my $yaml = Dump( $perl_data );
 
-    $args{file_path}->spew_utf8($yaml);
+    $args{file_path}->spew_raw($yaml);
 
     return 1;
 }
@@ -118,7 +118,7 @@ Config::Model::Backend::Yaml - Read and write config as a YAML data structure
 
 =head1 VERSION
 
-version 2.132
+version 2.134
 
 =head1 SYNOPSIS
 
@@ -283,7 +283,7 @@ This is free software, licensed under:
 
   The GNU Lesser General Public License, Version 2.1, February 1999
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -296,30 +296,6 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Config-Model-Backend-Yaml>
-
-=item *
-
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Config-Model-Backend-Yaml>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Config-Model-Backend-Yaml>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
