@@ -7,12 +7,11 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-use Config::Model::BackendMgr;
+use strict;
+use warnings;
+use utf8;
 
-$conf_dir = '/etc';
-$conf_file_name = 'test.yaml';
-
-$model->create_config_class(
+my @config_classes = ({
     name => 'Master',
 
     rw_config => {
@@ -22,16 +21,15 @@ $model->create_config_class(
     },
 
     element => [
-        true_bool  => { qw/type leaf value_type boolean/},
-        false_bool => { qw/type leaf value_type boolean/},
-        new_bool => { qw/type leaf value_type boolean/},
+        true_bool  => { qw/type leaf value_type boolean upstream_default 0/},
+        false_bool => { qw/type leaf value_type boolean upstream_default 0/},
+        new_bool => { qw/type leaf value_type boolean upstream_default 0/},
         null_value => { qw/type leaf value_type uniline/},
+        utf8_string => { qw/type leaf value_type uniline/},
     ]
-);
+});
 
-$model_to_test = "Master";
-
-@tests = (
+my @tests = (
     {
         name  => 'basic',
         check => [
@@ -46,6 +44,22 @@ $model_to_test = "Master";
             "/etc/test.yaml" => "---\nfalse_bool: false\nnew_bool: true\ntrue_bool: true\n",
         }
     },
+    {
+        name => 'utf8_data',
+        check => [
+            utf8_string => "Марцел Mézigue"
+        ],
+        file_contents_like => {
+            "/etc/test.yaml" => [ qr/Марцел Mézigue/ ] ,
+        }
+    }
 );
 
-1;
+return {
+    model_to_test => "Master",
+    conf_dir => '/etc',
+    conf_file_name => 'test.yaml',
+    config_classes => \@config_classes,
+    tests => \@tests
+};
+
